@@ -5,7 +5,7 @@ use Moose;
 use namespace::clean -except => [ 'meta' ];
 use 5.8.1; # might work with earlier perls but probably not
 
-our $VERSION = '1.000000';
+our $VERSION = '1.000001'; # 1.0.1
 
 with 'MooseX::Object::Pluggable';
 
@@ -101,6 +101,8 @@ Devel::REPL - a modern perl interactive shell
 
 Alternatively, use the 're.pl' script installed with the distribution
 
+  system$ re.pl
+
 =head1 AUTHOR
 
 Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
